psychopy_ext.models.HMAX.get_gabors — psychopy_ext 0.5.4 documentation
Author: Jonas Kubilius
Description: A framework for a rapid reproducible design, analysis and plotting of experiments in neuroscience and psychology

# psychopy_ext.models.HMAX.get_gabors

`HMAX.` `get_gabors`(filter_sizes_all, n_ori=4, k=2.1, sx=2.0943951023931953, sy=3.490658503988659, phase=0)

  Generates 2D Gabor filters. This is the original version of Gabor filters used in HMAX.

  Parameters
    filter_sizes_all: list (depth 2))
      A nested list (grouped by filter bands) of integer filter sizes
    n_ori: int
      A number of filter orientations (default: 4) Orientations are spaced by np.pi/n_ori
    k: float
      Gabor wave number (default: 2.1)
    sx: float
      Gabor sigma in x-dir (default: 2*np.pi * 1/3.)
    sy: float
      Gabor sigma in y-dir (default: 2*np.pi * 1/1.8)
    phase: int
      Gabor function phase (0 (default) for cosine (even),
        np.pi/2 for sine (odd))
  Returns
    gabors: list (depth 2)
      A nested list of filters of all orientations